(setq debug-on-error t)
                                        ; my own lisp scripts
(add-to-list 'load-path (expand-file-name "~/.emacs-files/lisp/"))

(set-default-font  "-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1")

(fset 'yes-or-no-p 'y-or-n-p)

(setq gnus-novice-user nil)
(setq gnus-expert-user nil)
;; german location
(set-language-environment 'german)
(set-terminal-coding-system 'iso-latin-1)
                                        ; Save space
;; (menu-bar-mode nil)
;; (tool-bar-mode nil)
                                        ; Handle .gz files
(auto-compression-mode t)
                                        ; Provide templates for new files
(auto-insert-mode t)
                                        ; Allow completions like em-s-region to complete to emacspeak-speak-region
(partial-completion-mode)
                                        ; gnus configuration
(setq gnus-init-file "~/.emacs-files/gnus.el")

                                        ; Use C-xaig to correct common typos
(setq abbrev-file-name "~/.emacs-files/abbrev_defs")

(if (file-exists-p abbrev-file-name)
    (quietly-read-abbrev-file))
(set-default 'abbrev-mode t)

;; make searches case-INsensitive
(setq-default case-fold-search t)

                                        ; do not use tabs for indentation
(setq-default indent-tabs-mode nil)

(setq
 ;; exec eval: statements in "Local Variables"
 enable-local-eval t
 ;; remove the startup message
 inhibit-startup-message t
 ;; don't add new lines when scrolling down
 next-line-add-newlines nil
 ;; make sure file ends with NEWLINE
 require-final-newline "yes"
 ;; delete excess backup versions
 delete-old-versions t
 ;; do not make backup files
 ;; make-backup-files nil
 ;; do only one line scrolling
 scroll-step 1
 ;; return to same line on a scroll back
 scroll-preserve-screen-position t
 ;; setting the defualt tabulation
 default-tab-width 2
 ;; dispaly time in the modeline
 display-time-24hr-format t
 display-time-day-and-date t
 ;; customize the calendar
 ;;european-calendar-style t
 ;;calendar-week-start-day 1
 ;;calendar-latitude 51.05
 ;;calendar-longitude -2.39
 ;;calendar-location-name "Ieper"
 ;; enable the debug
 ;; debug-on-error t
 ;; debug-on-quit t
 ;; paste at cursor NOT mouse pointer position
 mouse-yank-at-point t
 ;; auto-save-timeout 1800
 require-final-newline t
 search-highlight t
 ;; put point at the end of the output window
 compilation-scroll-output t
 ;; save all modified buffers without asking
 compilation-ask-about-save nil
 ;; do not ask for the compile command
 compilation-read-command nil
 compilation-window-height 7
 ;; work better but slower
 apropos-do-all t
 ;; autosave every 512 keyboard inputs
 auto-save-interval 512
 ;; limit the number of newest versions
 kept-new-versions 5
 ;; limit the number of oldest versions
 kept-old-versions 5
 auto-save-list-file-prefix "~/.backups/save-"
 tex-dvi-view-command "xdvi *")

(display-time)				; Display the time on modeline
(line-number-mode t)                  ; Display the line number on modeline
(column-number-mode t)              ; Display the column number on modeline
(setq-default kill-whole-line t)      ; Ctrl-k kills whole line if at col 0
(setq-default fill-column 75)		; Wrap at col 75
(setq-default tab-width 8)		; Show tabs as 8 cols
(setq-default transient-mark-mode t)    ; Turn on transient mark mode
(setq inhibit-startup-message t)        ; I'm sick of the welcome message
(setq minibuffer-max-depth nil)

;; Save all my backup files in a specific directory
;;(defun make-backup-file-name (file)
;; (concat "~/.autosave/" (file-name-nondirectory file)))

(put 'narrow-to-region 'disabled nil)

;; Color theme
(require 'color-theme)

;; Set's the first row ;;
(defun my-theme-set-default ()
	(interactive)
	(setq theme-current theme-circle)
	(funcall (car theme-current))
	)
     
;; Shows the current theme ;;
(defun my-describe-theme ()
	(interactive)
	(message "%s" (car theme-current)))
     
;; Set next theme ;;
(defun my-theme-cycle ()
	(interactive)
	(message "%S" (car theme-current))
	(setq theme-current (cdr theme-current))
	(if (null theme-current)
			(setq theme-current theme-circle))    
	(funcall (car theme-current))
	)
   
(setq 
 theme-circle (list
							 'color-theme-blue-mood
							 'color-theme-parus
							 'color-theme-jsc-dark
							 'color-theme-comidia
							 'color-theme-dark-gnus
							 )
     
 theme-current theme-circle
 )

;; Init ;;
(setq color-theme-is-global nil)
;;(my-theme-set-default)
(global-set-key [f12] 'my-theme-cycle)
;; For GNU Emacs
(unless (featurep 'xemacs)
  (set-background-color "Black")
  (set-foreground-color "White")
  (set-cursor-color "Orchid")
  (global-font-lock-mode))

(setq focus-follows-mouse t)

;; Font lock everything
(setq font-lock-maximum-size nil)

;; Turn on Auto Fill mode automatically in Text mode and related modes.
(add-hook 'text-mode-hook
          '(lambda () (auto-fill-mode 1)))


;; Turn on Flyspell mode automatically in Text mode and related modes.
(add-hook 'text-mode-hook
          '(lambda () (flyspell-mode)))

(defun anoop-love-letter-mode ()
  "Text mode for writing love letters."
  (interactive)
  (text-mode)
  (flyspell-mode)
  (auto-fill-mode))

(defun dos-unix ()
  (interactive)
  (goto-char (point-min))
  (while (search-forward "\r" nil t) (replace-match "")))

(defun unix-dos ()
  (interactive)
  (goto-char (point-min))
  (while (search-forward "\n" nil t) (replace-match "\r\n")))

;;
;; W3 related stuff
;;

(autoload 'css-mode "css-mode")
(setq 
 w3-user-fonts-take-precedence t
 w3-user-colors-take-precedence t
 w3-honor-stylesheets nil
 w3-use-terminal-characters nil
 w3-horizontal-rule-char 45
 w3-do-incremental-display t
 w3-do-scripting t
;; w3-default-homepage ""
 url-be-asynchronous t
 url-privacy-level (quote (email))
 url-automatic-caching nil
 ;; url-proxy-services (quote (("http" . "localhost:8080")))
 )
(message "W3 initialised")

;;
;; Useful key bindings
;;
(load-library "~/.emacs-files/keybindings.el")

(custom-set-variables
 '(load-home-init-file t t))
(custom-set-faces)

(setq-default
 frame-title-format
 (list
  '((buffer-file-name
     " %f"
     (dired-directory
      dired-directory
      (revert-buffer-function
       " %b"
       ("%b - Dir:  " default-directory)))))))

(setq-default
 icon-title-format
 (list
  '((buffer-file-name
     " %f"
     (dired-directory
      dired-directory
      (revert-buffer-function
       " %b"
       ("%b - Dir:  " default-directory)))))))


;; Print the ASCII table.
(defun ascii-table ()
  "Print the ascii table."
  (interactive)
  (switch-to-buffer "*ASCII*")
  (erase-buffer)
  (insert (format "ASCII characters up to number %d.\n" 254))
  (let ((i 0))
    (while (< i 254)
      (setq i (+ i 1))
      (insert (format "%4d %c\n" i i))))
  (beginning-of-buffer))


(require 'mabu-cc-init)

(global-set-key "\C-ct" 'mabu-timestamp)
(global-set-key "\C-cd" 'mabu-date)
(global-set-key "\C-cf" 'mabu-fixxme)

(autoload 'css-mode "css-mode")
(require 'css-mode)
(setq cssm-newline-before-closing-bracket t
			cssm-indent-function 'cssm-c-style-indenter
			)

;; ----------------------------------------------------------------------
;; ispell
;; ----------------------------------------------------------------------
(setq ispell-local-dictionary-alist 
			'(
				("german-ascii"									; german.aff
				 "[a-zA-Z\"]" "[^a-zA-Z\"]" "[']" t ("-C" "-d" "german") "~ascii" iso-8859-1)
				)
			;; 		("german-ascii"                         ; german.aff
			;;     "[a-zA-Z\"]" "[^a-zA-Z\"]" "[']" t ("-C" "-d" "german") "~ascii" iso-8859-1)
			;; 		)
			;; 	 ("german8-ascii"
			;;  "[a-zA-Z\304\326\334\344\366\337\374]" "[^a-zA-Z\304\326\334\344\366\337\374]" "[']" t
			;; 	("-C" "-d" "german") "~ascii" iso-8859-1)
			)

;; iso-accents
(setq iso-accents-enable '(?\")
			iso-language "german"
			)

(global-set-key "\C-ci" 'iso-accents-mode)

