;;--------------------------------------- all necessary requires
(require 'font-lock)
(require 'autoinsert)
(require 'mabu-skeletons)


;;----------------------------------------------------------------------
;; Auto-Mode Customization
;;----------------------------------------------------------------------
(mapcar
 '(lambda (auto)
		(setq auto-mode-alist
          (cons auto
                (delq (assoc (car auto) auto-mode-alist)
                      auto-mode-alist))))
 '(("\\.c\\'" 	 .  c-mode   )
	 ("\\.h\\'" 	 .  c++-mode )
	 ("\\.cpp\\'"  .  c++-mode )))

;;----------------------------------------------------------------------
;; Common Settings for C and C++ Mode
;;----------------------------------------------------------------------
(add-hook 'c-mode-common-hook 'turn-on-auto-fill) ; enable line wrap
(add-hook 'c-mode-common-hook 'turn-on-font-lock)	; enable syntax highlighting
(add-hook 'c-mode-common-hook
          (function
           (lambda ()
             (setq default-tab-width 2
									 indent-tabs-mode nil 
									 c-tab-always-indent t
									 transient-mark-mode t
									 comment-column 55 
                   fill-column 105
                   )
             )))

;;----------------------------------------------------------------------
;; Font Lock Mode (Text Highlighting)
;;----------------------------------------------------------------------

;; font highlighting of user types
(add-to-list 'c++-font-lock-extra-types "int8"   t)
(add-to-list 'c++-font-lock-extra-types "uint8"  t)
(add-to-list 'c++-font-lock-extra-types "int16"  t)
(add-to-list 'c++-font-lock-extra-types "uint16" t)
(add-to-list 'c++-font-lock-extra-types "int32"  t) 
(add-to-list 'c++-font-lock-extra-types "uint32" t) 
(add-to-list 'c++-font-lock-extra-types "int64"  t)
(add-to-list 'c++-font-lock-extra-types "uint64" t)



;;----------------------------------------------------------------------
;; C Mode
;;----------------------------------------------------------------------

(add-hook 'c-mode-hook
          (function
           (lambda ()
             (setq comment-start "//"
									 comment-end ""
									 c-comment-start-regexp c-C++-comment-start-regexp
									 ))))


;; compile command for c 
;; usefull for "Einfuehrung in die Strukturierte Programmierung"
(add-hook 'c-mode-hook
          (lambda ()
            (unless (or (file-exists-p "makefile")
                        (file-exists-p "Makefile"))
              (set (make-local-variable 'compile-command)
                   (concat "gcc " buffer-file-name
                           " -Wall"
                           " -o " (file-name-sans-extension buffer-file-name)
                           )))
            ))

;;----------------------------------------------------------------------
;; C++ Mode
;;----------------------------------------------------------------------
;; (setq mabu-makefile-default-compiler "g++")	;set default compiler for makefile auto insert

(add-hook 'c++-mode-hook
          (lambda ()
            (unless (or (file-exists-p "makefile")
                        (file-exists-p "Makefile"))
              (set (make-local-variable 'compile-command)
                   (concat "g++ " buffer-file-name
                           " -Wall"
                           " -o " (file-name-sans-extension buffer-file-name)
                           )))
            ))

;;----------------------------------------------------------------------
;; Indentation Style
;;----------------------------------------------------------------------
;; electric cc-mode indents
(defconst mabu-cc-style
  '((c-basic-offset . 2)
    (c-comment-only-line-offset . 4)
		(c-hanging-braces-alist . (
															 (substatement-open before after)
															 (statement before after)
															 (block-open before after)
															 (brace-list-open before after)
															 (brace-entry-open before after)
															 (block-close . c-snug-do-while)
															 (extern-lang-open before after)
															 (inexpr-class-open before after)
															 (inexpr-class-close before after)
															 )
														)
		(c-offsets-alist .
										 ((string . -1000)
											(c . c-lineup-comment)
											(defun-block-intro . +)
											(class-open . 0)
											(class-close . 0)
											(inline-open . 0)
											(inline-close . 0)
											(knr-argdecl-intro . +)
											(knr-argdecl . 0)
											(topmost-intro . 0)
											(topmost-intro-cont . 0)
											(member-init-intro . 0)
											(member-init-cont . 0)
											(inher-intro . +)
											(inher-cont . c-lineup-multi-inher)
											(block-open . -)
											(block-close . 0)
											(brace-list-open . 0)
											(brace-list-close . 0)
											(brace-list-intro . 0)
											(brace-list-entry . 0)
											(statement . c-lineup-runin-statements)
											(statement-cont . c-lineup-math)
											(statement-block-intro . +)
											(statement-case-intro . +)
											(substatement . +)
											(substatement-open . 0)
											(case-label . 0)
											(access-label . 0)
											(label . -)
											(do-while-closure . 0)
											(else-clause . 0)
											(comment-intro . c-lineup-comment)
											(arglist-intro . +)
											(arglist-cont . 0)
											(arglist-cont-nonempty . c-lineup-arglist)
											(arglist-close . +)
											(stream-op . c-lineup-streamop)
											(inclass . +)
											(cpp-macro . -1000)
											(friend . 0)))
		) "mabu C/C++ Programming Style")

(add-hook 'c-mode-common-hook
          (function
           (lambda ()
             (c-add-style "mabu" mabu-cc-style t))))

;;----------------------------------------------------------------------
;; Compile Settings
;;----------------------------------------------------------------------

(setq compilation-window-height 10
      compilation-scroll-output t
      )

;;----------------------------------------------------------------------
;; Makefile Settings
;;----------------------------------------------------------------------
(add-hook 'makefile-mode-hook 'turn-on-font-lock)

;;----------------------------------------------------------------------
;; Autoinserting text in empty files
;;----------------------------------------------------------------------
;; `M-x auto-insert' will put some predefined text at the beginning of the
;; buffer.


(add-hook 'find-file-hooks 'auto-insert) ; insert default contents into new files

;; ;; remove multiple definition for C / C++
;; (setq auto-insert-alist 
;; 			(delq (assoc '("\\.\\([Cc]\\|cc\\|cpp\\)\\'" . "C / C++ program") auto-insert-alist)
;; 						auto-insert-alist))

;; ;; Add Defaults for a C program
 (add-to-list 'auto-insert-alist '(("\\.c$" . "C program")
 																	nil
 																	(mabu-filename-shortdescription)
 ))

;; ;; Add Defaults for a C program
(add-to-list 'auto-insert-alist '(("\\.cpp$" . "C++ program")
 																	nil
 																	(mabu-filename-shortdescription)
 ))

(mapcar
 '(lambda (auto)
		(setq auto-insert-alist
          (cons auto
                (delq (assoc (car auto) auto-insert-alist)
                      auto-insert-alist))))
 '(
	 (("\\.\\([Hh]\\|hh\\|hpp\\)\\'" . "C / C++ header")
		nil 
		(mabu-cc-header-skeleton)
		)
   (("\\.\\([Cc]\\|cc\\|cpp\\)\\'" . "C / C++ program")
    nil       
		(mabu-filename-shortdescription) \n \n
		)
	 (("[Mm]akefile\\'" . "Makefile")
		nil
		(mabu-makefile-skeleton)
		)
	 ))

;;----------------------------------------------------------------------
;; Keybindings
;;----------------------------------------------------------------------
(add-hook 'c-mode-common-hook
          (lambda ()
						(local-set-key "\C-cc" 'compile)
            (local-set-key "\C-cC" 'recompile)
						(local-set-key "\M-\"c" 'mabu-minus)
						(local-set-key "\C-ct" 'mabu-timestamp)
						(local-set-key "\C-cd" 'mabu-date)
						(local-set-key "\C-cf" 'mabu-fixxme)
						))

(provide 'mabu-cc-init)
