(require 'skeleton)

(defvar mabu-address "Hafnerriegel 49, A-8010 Graz, Austria.")
(defvar mabu-fixme-string "FIXXME") 

(defvar mabu-makefile-default-compiler "gcc")

;;----------------------------------------------------------------------
;; General Skeletons
;;----------------------------------------------------------------------

;;----------------------------------------------------------------------
(define-skeleton mabu-timestamp
  "Inserts a timestamp"
  nil
  comment-start 
  "Time-stamp: <" 
  (format-time-string "%Y-%m-%d %T") " " 
  (user-login-name) "> " comment-end \n)

;;----------------------------------------------------------------------
(define-skeleton mabu-date
  "Inserts the current date "
  nil
  (format-time-string "%Y-%m-%d %T"))

;;----------------------------------------------------------------------
(define-skeleton mabu-fixxme
  "Inserts a fixxme comment"
  "Description: "
   '(setq v1 (concat "(" (user-full-name) ", " 
                     (format-time-string "%Y-%m-%d %T") ")"))
   comment-start 
   " " mabu-fixme-string
   v1 " -> " str 
   comment-end 
   \n \n
   _ 
   \n \n
   comment-start 
   " END " mabu-fixme-string
   v1
   comment-end \n)

;;----------------------------------------------------------------------
(define-skeleton mabu-minus
  "Inserts a comment line :
 \"----------------------------------------------------------------------\""
  nil
  comment-start 
  "----------------------------------------------------------------------" 
  comment-end)

;;----------------------------------------------------------------------
(define-skeleton mabu-asterisk
  "Inserts a comment line :
 \"**********************************************************************\"" 
  nil
  comment-start 
  "**********************************************************************" 
  comment-end)

;;**********************************************************************
;; Autoinsert  
;;**********************************************************************

;;---------------------------------------------------------------------
(define-skeleton mabu-filename-shortdescription 
	"Insert a short description about the file"
	"Short description: "
	comment-start " "
	(file-name-nondirectory buffer-file-name)
	" - " str  " " 
  comment-end \n 
	)

;;----------------------------------------------------------------------
(define-skeleton mabu-cc-header-skeleton
  "Inserts a template for a c++ header"
	nil
	(mabu-filename-shortdescription) \n \n
 	'(setq v1 (file-name-nondirectory buffer-file-name))
	'(setq v2 (concat (substring v1 0 (string-match "\\.[^.]*$" v1))
										"_"
										(substring v1 (1+ (string-match "\\.[^.]*$" v1)))
										"___"
										))
	"#ifndef " v2  \n
	"#define " v2 \n \n
	_
	 \n \n 
	"#endif " comment-start v2
	)

;;----------------------------------------------------------------------
(define-skeleton mabu-makefile-skeleton 
	"Inserts a Makefile"
	"Compiler? (gcc or. g++) "
	'(setq input mabu-makefile-default-compiler) 
	"OBJS = "  \n 
  "CC = " str \n
	"LD = " str \n
	"EXTRA_CCINCLUDES = 
CC_FLAGS = -c $(EXTRA_CCINCLUDES) -Wall
EXTRA_LIBDIRS = 
EXTRA_LIBS = 
EXECUTABLE = 
LD_FLAGS = -o $(EXECUTABLE) $(EXTRA_LIBDIRS) $(EXTRA_LIBS)

$(EXECUTABLE) : $(OBJS)
	$(LD) $(LD_FLAGS) $(OBJS)" \n \n
 _ \n \n
"all : $(EXECUTABLE)

clean : 
	rm $(OBJS) $(EXECUTABLE)")

;;----------------------------------------------------------------------
(define-skeleton mabu-c++-header-class
  "Inserts a header for a c++ class"
    nil
    '(setq v1 (skeleton-read "Class name: "  
           (capitalize (substring (file-name-nondirectory buffer-file-name)
                                  0 (string-match "\\.[^.]*$"
                                                  (file-name-nondirectory buffer-file-name))))
           ))
    (mabu-minus) \n
    comment-start \n
    comment-start v1 \n
    comment-start \n 
    comment-start (skeleton-read "Class description: ") \n comment-start \n
    comment-start \n \n                
    > "class "v1
   '(setq v2 (skeleton-read "Derived from: "))
    (if (null (string= v2 ""))
        (concat " : public " v2))
    \n
    "{" \n 
    > "private:" \n 
    > v1 "(const " v1 "&) {}" \n 
    > "const " v1 "& operator = (const " v1 "&) { return(*this); }" \n \n
    > "public:" \n 
    > v1 "();" \n 
    > "virtual ~" v1 "();" 
    \n \n
     "};" '(c-indent-command) \n
    )

(provide 'mabu-skeletons)




